Index: apps/app_mixmonitor.c
===================================================================
--- apps/app_mixmonitor.c	(revision 418785)
+++ apps/app_mixmonitor.c	(working copy)
@@ -119,6 +119,12 @@
 						<argument name="chanvar" required="true" />
 						<para>Stores the MixMonitor's ID on this channel variable.</para>
 					</option>
+					<option name="p">
+						<para>Play a beep on the channel that starts the recording.</para>
+					</option>
+					<option name="P">
+						<para>Play a beep on the channel that stops the recording.</para>
+					</option>
 					<option name="m">
 						<argument name="mailbox" required="true" />
 						<para>Create a copy of the recording as a voicemail in the indicated <emphasis>mailbox</emphasis>(es)
@@ -325,6 +331,8 @@
 	MUXFLAG_UID = (1 << 9),
 	MUXFLAG_VMRECIPIENTS = (1 << 10),
 	MUXFLAG_BEEP = (1 << 11),
+	MUXFLAG_BEEP_START = (1 << 12),
+	MUXFLAG_BEEP_STOP = (1 << 13)
 };
 
 enum mixmonitor_args {
@@ -343,6 +351,8 @@
 	AST_APP_OPTION('a', MUXFLAG_APPEND),
 	AST_APP_OPTION('b', MUXFLAG_BRIDGED),
 	AST_APP_OPTION_ARG('B', MUXFLAG_BEEP, OPT_ARG_BEEP_INTERVAL),
+	AST_APP_OPTION('p', MUXFLAG_BEEP_START),
+	AST_APP_OPTION('P', MUXFLAG_BEEP_STOP),
 	AST_APP_OPTION_ARG('v', MUXFLAG_READVOLUME, OPT_ARG_READVOLUME),
 	AST_APP_OPTION_ARG('V', MUXFLAG_WRITEVOLUME, OPT_ARG_WRITEVOLUME),
 	AST_APP_OPTION_ARG('W', MUXFLAG_VOLUME, OPT_ARG_VOLUME),
@@ -657,6 +667,14 @@
 
 	ast_mutex_unlock(&mixmonitor->mixmonitor_ds->lock);
 
+	ast_channel_lock(mixmonitor->autochan->chan);
+	if (ast_test_flag(mixmonitor, MUXFLAG_BEEP_START)) {
+		if (ast_stream_and_wait(mixmonitor->autochan->chan, "beep", "")) {
+			ast_log(LOG_WARNING, "Failed to play a beep when starting the recording on '%s'.\n",
+				ast_channel_name(mixmonitor->autochan->chan));
+		}
+	}
+	ast_channel_unlock(mixmonitor->autochan->chan);
 
 	/* The audiohook must enter and exit the loop locked */
 	ast_audiohook_lock(&mixmonitor->audiohook);
@@ -734,6 +752,15 @@
 									ast_channel_name(mixmonitor->autochan->chan),
 									mixmonitor->filename);
 
+	ast_channel_lock(mixmonitor->autochan->chan);
+	if (ast_test_flag(mixmonitor, MUXFLAG_BEEP_STOP)) {
+		if (ast_stream_and_wait(mixmonitor->autochan->chan, "beep", "")) {
+			ast_log(LOG_WARNING, "Failed to play a beep when stopping the recording on '%s'.\n",
+				ast_channel_name(mixmonitor->autochan->chan));
+		}
+	}
+	ast_channel_unlock(mixmonitor->autochan->chan);
+
 	ast_audiohook_unlock(&mixmonitor->audiohook);
 
 	ast_autochan_destroy(mixmonitor->autochan);
@@ -1164,6 +1191,7 @@
 	if (!ast_channel_datastore_remove(chan, datastore)) {
 		ast_datastore_free(datastore);
 	}
+
 	ast_channel_unlock(chan);
 
 	if (!ast_strlen_zero(beep_id)) {
